import javax.naming.InitialContext;

import javax.jms.*;

public class AsyncReceiver implements MessageListener {
    public static void main(String[] args) throws Exception {
        // get the initial context
        InitialContext jndictx = new InitialContext();

        // lookup the queue object and connection factory
        Queue queue = (Queue) jndictx.lookup("dynamicQueues/KMA");
        ConnectionFactory connFactory = (ConnectionFactory) jndictx
            .lookup("ConnectionFactory");

        // close the naming context
        jndictx.close();

        // get the JMS context
        try (JMSContext ctx = connFactory.createContext()) {
            // create a consumer, configure it and get a message
            JMSConsumer consumer = ctx.createConsumer(queue);
            // set an asynchronous message listener
            AsyncReceiver asyncReceiver = new AsyncReceiver();
            consumer.setMessageListener(asyncReceiver);

            // wait for messages
            System.out.print("waiting for messages");
            for (int i = 0; i < 10; i++) {
                Thread.sleep(1000);
                System.out.print(".");
            }
            System.out.println();
        } catch (JMSRuntimeException e) {
            System.out.println("Problem with the JMS server: " + e);
        }
    }

    /**
       This method is called asynchronously by JMS when a message arrives
       at the queue. Client applications must not throw any exceptions in
       the onMessage method.
       @param message A JMS message.
    */
    public void onMessage(Message message)
    {
        TextMessage msg = (TextMessage) message;
        try {
            System.out.println("received: " + msg.getText());
        } catch (JMSException ex) {
            ex.printStackTrace();
        }
    }
}
